==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/operation/SanitizeType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SanitizeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SanitizeType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="metadata" type="{http://schema.webpdf.de/1.0/operation}SanitizeMetadataType" minOccurs="0"/&gt;
 *         &lt;element name="layers" type="{http://schema.webpdf.de/1.0/operation}SanitizeLayersType" minOccurs="0"/&gt;
 *         &lt;element name="tags" type="{http://schema.webpdf.de/1.0/operation}SanitizeTagsType" minOccurs="0"/&gt;
 *         &lt;element name="outlines" type="{http://schema.webpdf.de/1.0/operation}SanitizeOutlinesType" minOccurs="0"/&gt;
 *         &lt;element name="attachments" type="{http://schema.webpdf.de/1.0/operation}SanitizeAttachmentsType" minOccurs="0"/&gt;
 *         &lt;element name="forms" type="{http://schema.webpdf.de/1.0/operation}SanitizeFormsType" minOccurs="0"/&gt;
 *         &lt;element name="annotations" type="{http://schema.webpdf.de/1.0/operation}SanitizeAnnotationsType" minOccurs="0"/&gt;
 *         &lt;element name="pages" type="{http://schema.webpdf.de/1.0/operation}SanitizePagesType" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SanitizeType", propOrder = {

})
public class SanitizeType {

    protected SanitizeMetadataType metadata;
    protected SanitizeLayersType layers;
    protected SanitizeTagsType tags;
    protected SanitizeOutlinesType outlines;
    protected SanitizeAttachmentsType attachments;
    protected SanitizeFormsType forms;
    protected SanitizeAnnotationsType annotations;
    protected SanitizePagesType pages;

    /**
     * Gets the value of the metadata property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeMetadataType }
     *     
     */
    public SanitizeMetadataType getMetadata() {
        return metadata;
    }

    /**
     * Sets the value of the metadata property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeMetadataType }
     *     
     */
    public void setMetadata(SanitizeMetadataType value) {
        this.metadata = value;
    }

    public boolean isSetMetadata() {
        return (this.metadata!= null);
    }

    /**
     * Gets the value of the layers property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeLayersType }
     *     
     */
    public SanitizeLayersType getLayers() {
        return layers;
    }

    /**
     * Sets the value of the layers property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeLayersType }
     *     
     */
    public void setLayers(SanitizeLayersType value) {
        this.layers = value;
    }

    public boolean isSetLayers() {
        return (this.layers!= null);
    }

    /**
     * Gets the value of the tags property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeTagsType }
     *     
     */
    public SanitizeTagsType getTags() {
        return tags;
    }

    /**
     * Sets the value of the tags property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeTagsType }
     *     
     */
    public void setTags(SanitizeTagsType value) {
        this.tags = value;
    }

    public boolean isSetTags() {
        return (this.tags!= null);
    }

    /**
     * Gets the value of the outlines property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeOutlinesType }
     *     
     */
    public SanitizeOutlinesType getOutlines() {
        return outlines;
    }

    /**
     * Sets the value of the outlines property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeOutlinesType }
     *     
     */
    public void setOutlines(SanitizeOutlinesType value) {
        this.outlines = value;
    }

    public boolean isSetOutlines() {
        return (this.outlines!= null);
    }

    /**
     * Gets the value of the attachments property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeAttachmentsType }
     *     
     */
    public SanitizeAttachmentsType getAttachments() {
        return attachments;
    }

    /**
     * Sets the value of the attachments property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeAttachmentsType }
     *     
     */
    public void setAttachments(SanitizeAttachmentsType value) {
        this.attachments = value;
    }

    public boolean isSetAttachments() {
        return (this.attachments!= null);
    }

    /**
     * Gets the value of the forms property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeFormsType }
     *     
     */
    public SanitizeFormsType getForms() {
        return forms;
    }

    /**
     * Sets the value of the forms property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeFormsType }
     *     
     */
    public void setForms(SanitizeFormsType value) {
        this.forms = value;
    }

    public boolean isSetForms() {
        return (this.forms!= null);
    }

    /**
     * Gets the value of the annotations property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeAnnotationsType }
     *     
     */
    public SanitizeAnnotationsType getAnnotations() {
        return annotations;
    }

    /**
     * Sets the value of the annotations property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeAnnotationsType }
     *     
     */
    public void setAnnotations(SanitizeAnnotationsType value) {
        this.annotations = value;
    }

    public boolean isSetAnnotations() {
        return (this.annotations!= null);
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizePagesType }
     *     
     */
    public SanitizePagesType getPages() {
        return pages;
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizePagesType }
     *     
     */
    public void setPages(SanitizePagesType value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/SanitizeType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Simplifies document structures, deletes metadata, and flattens page contents in order to remove confidential information that could be hidden in the document structure. Subelements can be used to exempt specific content from this operation or to configure how it will be handled in greater detail. If a subelement is not passed, the represented function will be considered to be enabled and configured with the corresponding default values.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for SanitizeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="SanitizeType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="metadata" type="{http://schema.webpdf.de/1.0/operation}SanitizeMetadataType" minOccurs="0"/>
 *         <element name="layers" type="{http://schema.webpdf.de/1.0/operation}SanitizeLayersType" minOccurs="0"/>
 *         <element name="tags" type="{http://schema.webpdf.de/1.0/operation}SanitizeTagsType" minOccurs="0"/>
 *         <element name="outlines" type="{http://schema.webpdf.de/1.0/operation}SanitizeOutlinesType" minOccurs="0"/>
 *         <element name="attachments" type="{http://schema.webpdf.de/1.0/operation}SanitizeAttachmentsType" minOccurs="0"/>
 *         <element name="forms" type="{http://schema.webpdf.de/1.0/operation}SanitizeFormsType" minOccurs="0"/>
 *         <element name="annotations" type="{http://schema.webpdf.de/1.0/operation}SanitizeAnnotationsType" minOccurs="0"/>
 *         <element name="pages" type="{http://schema.webpdf.de/1.0/operation}SanitizePagesType" minOccurs="0"/>
 *         <element name="actions" type="{http://schema.webpdf.de/1.0/operation}SanitizeActionsType" minOccurs="0"/>
 *       </all>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SanitizeType", propOrder = {

})
public class SanitizeType {

    protected SanitizeMetadataType metadata;
    protected SanitizeLayersType layers;
    protected SanitizeTagsType tags;
    protected SanitizeOutlinesType outlines;
    protected SanitizeAttachmentsType attachments;
    protected SanitizeFormsType forms;
    protected SanitizeAnnotationsType annotations;
    protected SanitizePagesType pages;
    protected SanitizeActionsType actions;

    /**
     * Gets the value of the metadata property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeMetadataType }
     *     
     */
    public SanitizeMetadataType getMetadata() {
        return metadata;
    }

    /**
     * Sets the value of the metadata property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeMetadataType }
     *     
     */
    public void setMetadata(SanitizeMetadataType value) {
        this.metadata = value;
    }

    public boolean isSetMetadata() {
        return (this.metadata!= null);
    }

    /**
     * Gets the value of the layers property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeLayersType }
     *     
     */
    public SanitizeLayersType getLayers() {
        return layers;
    }

    /**
     * Sets the value of the layers property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeLayersType }
     *     
     */
    public void setLayers(SanitizeLayersType value) {
        this.layers = value;
    }

    public boolean isSetLayers() {
        return (this.layers!= null);
    }

    /**
     * Gets the value of the tags property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeTagsType }
     *     
     */
    public SanitizeTagsType getTags() {
        return tags;
    }

    /**
     * Sets the value of the tags property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeTagsType }
     *     
     */
    public void setTags(SanitizeTagsType value) {
        this.tags = value;
    }

    public boolean isSetTags() {
        return (this.tags!= null);
    }

    /**
     * Gets the value of the outlines property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeOutlinesType }
     *     
     */
    public SanitizeOutlinesType getOutlines() {
        return outlines;
    }

    /**
     * Sets the value of the outlines property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeOutlinesType }
     *     
     */
    public void setOutlines(SanitizeOutlinesType value) {
        this.outlines = value;
    }

    public boolean isSetOutlines() {
        return (this.outlines!= null);
    }

    /**
     * Gets the value of the attachments property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeAttachmentsType }
     *     
     */
    public SanitizeAttachmentsType getAttachments() {
        return attachments;
    }

    /**
     * Sets the value of the attachments property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeAttachmentsType }
     *     
     */
    public void setAttachments(SanitizeAttachmentsType value) {
        this.attachments = value;
    }

    public boolean isSetAttachments() {
        return (this.attachments!= null);
    }

    /**
     * Gets the value of the forms property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeFormsType }
     *     
     */
    public SanitizeFormsType getForms() {
        return forms;
    }

    /**
     * Sets the value of the forms property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeFormsType }
     *     
     */
    public void setForms(SanitizeFormsType value) {
        this.forms = value;
    }

    public boolean isSetForms() {
        return (this.forms!= null);
    }

    /**
     * Gets the value of the annotations property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeAnnotationsType }
     *     
     */
    public SanitizeAnnotationsType getAnnotations() {
        return annotations;
    }

    /**
     * Sets the value of the annotations property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeAnnotationsType }
     *     
     */
    public void setAnnotations(SanitizeAnnotationsType value) {
        this.annotations = value;
    }

    public boolean isSetAnnotations() {
        return (this.annotations!= null);
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizePagesType }
     *     
     */
    public SanitizePagesType getPages() {
        return pages;
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizePagesType }
     *     
     */
    public void setPages(SanitizePagesType value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    /**
     * Gets the value of the actions property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeActionsType }
     *     
     */
    public SanitizeActionsType getActions() {
        return actions;
    }

    /**
     * Sets the value of the actions property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeActionsType }
     *     
     */
    public void setActions(SanitizeActionsType value) {
        this.actions = value;
    }

    public boolean isSetActions() {
        return (this.actions!= null);
    }

}
